@@ -4,7 +4,7 @@
 import numpy as np
 
 from kivy.app import App
-from kivy.logger import Logger
+from loguru import logger
 from kivy.properties import (
     NumericProperty,
     StringProperty,
@@ -17,8 +17,8 @@ from kivy.uix.boxlayout import BoxLayout
 from kivy.metrics import dp
 from kivy.lang import Builder
 from kivy.core.window import Window
+from kivymd.uix.behaviors import HoverBehavior
 
-from jocular.hoverable import HoverBehavior
 from jocular.metrics import Metrics
 from jocular.component import Component
 from jocular.uranography import make_tile
@@ -31,7 +31,7 @@ Builder.load_string(
 <PropVal>:
     canvas.before:
         Color:
-            rgba: .3, .3, .3, .7
+            rgba: .3, .3, .3, .9
         Rectangle:
             pos: self.pos
             size: self.size
@@ -43,7 +43,8 @@ Builder.load_string(
         halign: 'left'
         text_size: self.size
         color: app.lowlight_color
-        font_size: app.info_font_size
+        # font_size: app.info_font_size
+        font_size: app.form_font_size
         background_color: .6, 0, .6, 0
         width: dp(100)
         padding: dp(5), dp(1)
@@ -54,7 +55,8 @@ Builder.load_string(
         halign: 'left'
         text_size: self.size
         color: app.lowlight_color
-        font_size: app.info_font_size
+        # font_size: app.info_font_size
+        font_size: app.form_font_size
         background_color: .6, 0, .6, 0
         width: dp(250)
         text: '{:}'.format(root.value)
@@ -78,7 +80,8 @@ Builder.load_string(
         valign: 'middle'
         text_size: self.size
         color: root.title_color
-        font_size: str(int(app.info_font_size[:-2]) + 4) + 'sp'
+        # font_size: str(int(app.info_font_size[:-2]) + 4) + 'sp'
+        font_size: str(int(app.form_font_size[:-2]) + 4) + 'sp'
         width: dp(350)
         text: '[b]{:}[/b]'.format(root.Name)
 
@@ -91,15 +94,15 @@ Builder.load_string(
 <Annotation>:
     size_hint: None, None
     size: self.texture_size
-    font_size: '15sp'
-    text_size: None, None  # forces size to be that of text
+    font_size: '15sp' if self.pinned else '20sp'
+    text_size: None, None  # forces size to be that of text
     color: (self.label_color if self.pinned else self.marker_color) + [self.visible]
     pos: (self.lab_x - self.width / 2, self.lab_y - self.height / 2) if self.center and not self.pinned else (self.lab_x, self.lab_y)
 
 <AnnotCluster>:
     canvas:
         Color:
-            rgb: 1, 0, 0
+            rgb: 1, 1, 1
             a: 1 if self.visible else 0
         Line:
             circle: self.sx, self.sy, self.radius
@@ -122,12 +125,12 @@ Builder.load_string(
 <AnnotFOV>:
     canvas:
         Color:
-            rgb: .8, .8, .8
+            rgb: .4, .4, .4
             a: 1 if self.visible else 0
         Line:
             points: [self.sx - self.length/2, self.sy, self.sx + self.length/2, self.sy]
-            width: 1
-    color: .8, .8, .8, 1
+            width: 3
+    color: 1, .4, .4, 1
 
 '''
 )
@@ -179,7 +182,7 @@ class Annotation(Label, HoverBehavior):
         if not self.pinned:
             lab = self.info['Name']
             self.font_size = '15sp'
-            # for quasars, label with mag + redshift
+            # for quasars, label with mag + redshift
             if self.ot == 'QS':
                 lab = '{:4.1f}'.format(self.info['Mag'])
                 z = self.info.get('z', '?')
@@ -225,7 +228,7 @@ class Annotation(Label, HoverBehavior):
         self.sx, self.sy = self.mapping(self.px, self.py)
         self.visible = self.in_eyepiece(self.xc, self.yc, self.r2) and self.display
 
-        #  display if visible and set to display
+        # display if visible and set to display
         if self.visible:
             bx, by = self.mapping(self.bx, self.by)
             if self.pinned:
@@ -243,9 +246,9 @@ class AnnotCluster(Annotation):
 
 
 class AnnotQuasar(Annotation):
-    # a couple of lines a few pix from QSO
+    # a couple of lines set a few pix from QSO
     length = NumericProperty(20)  # indicator line length in pixels
-    gap = NumericProperty(10)  # gap from quasar to line in pixels
+    gap = NumericProperty(20)  # gap from quasar to line in pixels
 
 
 class AnnotFOV(Annotation):
@@ -315,7 +318,7 @@ class DSOPopup(BoxLayout):
             self.x = min(pos[0] + dp(9), Window.width - self.minimum_width - dp(20))
             self.y = min(pos[1], Window.height - self.minimum_height - dp(20))
         except Exception as e:
-            Logger.debug('Annotator: DSOPopup.display ({:})'.format(e))
+            logger.debug('DSOPopup.display issue ({:})'.format(e))
 
     def hide(self):
         self.x = 10 * Window.width
@@ -340,8 +343,10 @@ class Annotator(Component):
         # remove previous annotations
         gui = App.get_running_app().gui
         if self.has_annotations():
+            n_annots = len(self.annotations)
             for k in self.annotations:
                 gui.remove_widget(k)
+            logger.info('Cleared {:d} annotations'.format(n_annots))
             self.annotations = []
 
     def has_annotations(self):
@@ -356,6 +361,11 @@ class Annotator(Component):
             for annot in self.annotations:
                 annot.display = False
             mesg = 'off'
+        # just keep scale marker
+        elif ml <= -3:
+            for annot in self.annotations:
+                annot.display = annot.info.get('Name', '') == 'FOV'
+            mesg = 'fov'
         # if below 0, just turn on pinned annotations
         elif ml < 0:
             for annot in self.annotations:
@@ -397,7 +407,7 @@ class Annotator(Component):
         Component.get('View').orientation = solver.north
 
         # find objects in FOV from tile large enough to encompass sensor
-        w, h = solver.w, solver.h
+        w, h = solver.im_width, solver.im_height
         deg_per_pixel = float(solver.FOV_h / h)
         fov = 1.5 * max(solver.FOV_w, solver.FOV_h)
         tile = make_tile(solver.tile_ra0, solver.tile_dec0, fov=fov)
@@ -410,28 +420,33 @@ class Annotator(Component):
         self.annotations = [
             AnnotFOV(
                 text="1'",
-                info={'Name': ''},
-                color=[0.6, 0.6, 0.6, 1],
+                info={'Name': 'FOV'},
+                color=[0.4, 0.4, 0.4, 1],
                 px=0,
                 py=0,
                 bx=1 / (3600 * deg_per_pixel),
                 by=0,
+                mag=-3,
+                pinned=True
             )
         ]
 
-        # object type properties and defaults
+        # object type properties and defaults
         OT_props = cats.get_object_types()
         default_props = {'name': '?', 'col': [0, 0, 0], 'text': '¤', 'mag': 0}
 
         ''' dsos is a dict of names and properties
         '''
+
+        atypes = []
         for nm, info in dsos.items():
             px, py = solver.ra_dec_to_pixels(info['RA'], info['Dec'])
             px, py = float(px[0]), float(py[0])
-            #  check it is actually within the image dimensions
+            # check it is actually within the image dimensions
             if (px >= 0) & (py >= 0) & (px < w) & (py < h):
                 # replace OT acronym in info by full OT name
                 ot = info['OT']
+                atypes += [ot] # diagnostic
                 props = OT_props.get(ot, default_props)
                 # fill in missing props
                 for k, v in default_props.items():
@@ -444,7 +459,7 @@ class Annotator(Component):
                 center = True
                 if ot in {'OC', 'GC', 'CG', 'GG', 'G+', 'PG'}:
                     cls = AnnotCluster
-                    diam *= 1.3  # make circle slightly larger
+                    diam *= 1.3  # make circle slightly larger
                     center = False
                 elif ot in {'QS', 'BQ', 'DQ'}:
                     cls = AnnotQuasar
@@ -457,7 +472,6 @@ class Annotator(Component):
                         diam *= 1.5
 
                 # diam is in arcmin
-                # print('Obj: {:} OT {:} diam: {:}'.format(info['Name'], ot, diam))
                 pixel_rad = (((diam / (2 * 60.0)) / deg_per_pixel)) / 2**.5
 
                 self.annotations += [cls(
@@ -475,14 +489,14 @@ class Annotator(Component):
                 ]
 
         # create annotation labels
-        mapping = Component.get('View').to_parent
+        mapping = Component.get('View').scatter.to_parent
         xc, yc = Metrics.get('origin')
         r2 = Metrics.get('inner_radius') ** 2
         gui = App.get_running_app().gui
         for lab in self.annotations:
             gui.add_widget(lab, index=101)
             lab.update(mapping=mapping, xc=xc, yc=yc, r2=r2)
-            #  sort out situations where several have same target name
+            # sort out situations where several have same target name
             if lab.info['Name'] == target:
                 lab.pin()
         self.on_mag_limit()
@@ -493,7 +507,7 @@ class Annotator(Component):
         if not self.has_annotations():
             return
 
-        mapping = Component.get('View').to_parent
+        mapping = Component.get('View').scatter.to_parent
         xc, yc = Metrics.get('origin')
         r2 = Metrics.get('inner_radius') ** 2
         for annot in self.annotations:
