@@ -1,10 +1,10 @@
 ''' Luminance channel manipulations, including B & W, stretch etc
 '''
 
+import math
 import numpy as np
 
 from kivy.app import App
-from kivy.uix.label import Label
 from kivy.uix.boxlayout import BoxLayout
 from kivy.metrics import dp
 from kivy.properties import BooleanProperty, NumericProperty, OptionProperty
@@ -14,7 +14,38 @@ from jocular.stretch import stretch
 from jocular.gradient import estimate_gradient, estimate_background, image_stats
 from jocular.component import Component
 from jocular.metrics import Metrics
+from kivy.lang import Builder
 
+Builder.load_string(
+'''
+
+<StatsPanel>:
+    adustr: _adu
+    perstr: _per
+    size_hint: None, None 
+    size: dp(400), dp(100) 
+    orientation: 'vertical'
+    MDLabel:
+        id: _adu
+        size_hint: None, None
+        size: dp(400), dp(25)
+        theme_text_color: 'Custom'
+        text_color: .6, .6, .6, 1
+        font_size: '16sp'
+        halign: 'center'
+    MDLabel:
+        id: _per
+        size_hint: None, None
+        size: dp(400), dp(25)
+        theme_text_color: 'Custom'
+        text_color: .6, .6, .6, 1
+        font_size: '16sp'
+        halign: 'center'
+
+''')
+
+class StatsPanel(BoxLayout):
+    pass
 
 class Monochrome(Component):
 
@@ -33,6 +64,8 @@ class Monochrome(Component):
     autoblack = BooleanProperty(True)
     show_image_stats = BooleanProperty(False)
 
+    save_settings = ['gradient', 'white', 'black', 'p1', 'lift', 'noise_reduction', 'autoblack', 'show_image_stats', 'stretch']
+
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         self.mono = None  # not 100% sure why this is needed on init
@@ -42,8 +75,8 @@ class Monochrome(Component):
 
     def on_new_object(self):
         self.mono = None
-        self.lum = None  #  luminosity (after applying stretch, B/W etc to mono)
-        self._gradient = None  #  pixel-by-pixel zero-mean gradient estimate to subtract
+        self.lum = None  # luminosity (after applying stretch, B/W etc to mono)
+        self._gradient = None  # pixel-by-pixel zero-mean gradient estimate to subtract
         self._std_background = None  # std dev of background estimated from gradient
         self._blackpoint = None  # automatic estimate of blackpoint
         self._n = 0
@@ -71,7 +104,7 @@ class Monochrome(Component):
         self.adjust_lum()
 
     def on_fine(self, *args):
-        #  move black by a tiny amount
+        # move black by a tiny amount
         if not self.autoblack:
             newblack = min(1, max(0, self.black + 0.1 * self.fine))
             self.gui.set("black", float(newblack))  # causes update
@@ -87,14 +120,16 @@ class Monochrome(Component):
         self.gui.set("black", float(self._blackpoint))
 
     def update_gradient(self, im):
-        #  Estimate gradient and normalise to zero mean
+        # Estimate gradient and normalise to zero mean
         g = estimate_gradient(im)
         self._gradient = g - np.mean(g)
 
     def display_sub(self, im, do_gradient=False):
-        """Called by Stacker when user selects sub, and by Capture, when displaying short subs
-        Only compute gradient if light sub from stacker, not when calibration, nor when short
-        """
+        ''' Called by Stacker when user selects sub, and by Capture, when 
+            displaying short subs. Only compute gradient if light sub from 
+            stacker, not when calibration, nor when short
+            v0.5 added: also compute grad if dims changed
+        '''
 
         # ensure we are displaying subs
         if self.stacker.sub_or_stack == "stack":
@@ -104,13 +139,17 @@ class Monochrome(Component):
         self.mono = im
         if do_gradient:
             self.update_gradient(im)
+        # new in v0.5: if shape changes, update gradient
+        elif self._gradient is not None and self._gradient.shape != im.shape:
+            self.update_gradient(im) 
         if self.autoblack:
             self.update_blackpoint(im)
         self.view.display_image(self.luminance())
 
     def adjust_lum(self, *args):
-        """User has changed control position so generate luminance and either
-        display it (if sub or in mono mode) or advise multispectral of the update"""
+        ''' User has changed control position so generate luminance and either
+            display it (if sub or in mono mode) or advise multispectral of the update
+        '''
 
         lum = self.luminance()
         if self.stacker.sub_or_stack == "sub":
@@ -147,12 +186,12 @@ class Monochrome(Component):
         if self.show_image_stats:
             self.compute_image_stats()
 
-        #  subtract some % of gradient if we have it computed (not the case for short subs)
+        # subtract some % of gradient if we have it computed (not the case for short subs)
         if (self._gradient is not None) and (self.gradient > 0.1):
             im = im - (self.gradient / 100) * self._gradient
 
         # set black based on automatic blackpoint estimate and lift setting
-        #  we also allow lift settings in non-auto case
+        # we also allow lift settings in non-auto case
 
         if self.autoblack and (self._std_background is not None):
             black = max(0, self._blackpoint - self.lift * self._std_background)
@@ -178,54 +217,52 @@ class Monochrome(Component):
             if self._std_background is None
             else self.lift * self._std_background,
         )
+
         return im
 
     def compute_image_stats(self):
-        if hasattr(self, "mono") and self.mono is not None:
-            im = self.mono
-            stats = image_stats(im)
-            for s in [
-                "min",
-                "background",
-                "100 x std. dev.",
-                "central 75%",
-                "99.9 percentile",
-                "99.99 percentile",
-                "max",
-            ]:
-                self.image_stats_fields[s].text = "{:}: {:.10f}%".format(
-                    s, 100 * stats[s]
-                )
+        if not hasattr(self, "mono") or self.mono is None or not hasattr(self, 'statspanel'):
+            return
+        im = self.mono
+        stats = image_stats(im)
+        stats = {k: 0 if math.isnan(v) else v for k, v in stats.items()}
+        try:
+            adu = {k: int(2**16 * v) for k, v in stats.items()}
+            per = {k: (100 * v) for k, v in stats.items()}
 
-    #  use kv for these?
-    def make_image_stats_panel(self):
-        p = BoxLayout(
-            size_hint=(None, None), size=(dp(200), dp(200)), orientation="vertical"
-        )
-        App.get_running_app().gui.add_widget(p)
-        self.image_stats_fields = {}
-        for s in [
-            "min",
-            "background",
-            "100 x std. dev.",
-            "central 75%",
-            "99.9 percentile",
-            "99.99 percentile",
-            "max",
-        ]:
-            self.image_stats_fields[s] = l = Label(
-                text=s, size_hint=(None, None), size=(dp(200), dp(25))
-            )
-            p.add_widget(l)
-        return p
+            self.statspanel.perstr.text = \
+                'percent {:.1f}-{:.1f} mean {:.1f} bg {:.1f} max {:.1f}'.format(
+                per['min'], per['max'], per['mean'], per['background'], per['99.99'])
+            self.statspanel.adustr.text = \
+                'ADU {:d}-{:d} mean {:.0f} bg {:.0f} max {:.0f}'.format(
+                adu['min'], adu['max'], adu['mean'], adu['background'], adu['99.99'])
+        except:
+            pass
+
+    # def make_image_stats_panel(self):
+    #     p = BoxLayout(
+    #         size_hint=(None, None), 
+    #         size=(dp(400), dp(100)), 
+    #         orientation="vertical"
+    #     )
+    #     App.get_running_app().gui.add_widget(p)
+    #     self.statfields = {
+    #         'adu': MDLabel(halign='center', size_hint=(None, None), size=(dp(400), dp(25))),
+    #         'per': MDLabel(halign='center', size_hint=(None, None), size=(dp(400), dp(25)))
+    #         }
+    #     p.add_widget(self.statfields['adu'])
+    #     p.add_widget(self.statfields['per'])
+
+    #     return p
 
     def on_show_image_stats(self, *args):
+        if not hasattr(self, 'statspanel'):
+            self.statspanel = StatsPanel()
+            App.get_running_app().gui.add_widget(self.statspanel)            
         if self.show_image_stats:
-            if not hasattr(self, "image_stats"):
-                self.image_stats = self.make_image_stats_panel()
             cx, cy = Metrics.get("origin")
-            self.image_stats.center_x = cx
-            self.image_stats.center_y = Window.height - dp(150)
+            self.statspanel.center_x = cx
+            self.statspanel.center_y = dp(150)
             self.compute_image_stats()
         else:
-            self.image_stats.y = 2 * Window.height
+            self.statspanel.y = 2 * Window.height
