@@ -7,9 +7,27 @@ import numpy as np
 from scipy.stats import trimboth
 from skimage.color import rgb2lab, lab2rgb
 from skimage.transform import resize, rescale
-from kivy.properties import ConfigParserProperty, NumericProperty
+
+from kivy.properties import BooleanProperty, NumericProperty, StringProperty
 from jocular.gradient import estimate_gradient, estimate_background
 from jocular.component import Component
+from jocular.settingsmanager import Settings
+
+def bin_image(im, binfac=2, rescale_to_orig=True):
+    ''' bin and rescale to original size; 
+        in v0.5 added the preserve range option
+    '''
+    binfac = int(binfac)
+    if binfac == 1:
+        return im
+    if binfac < 1:
+        return im
+    im2 = rescale(im, 1 / binfac, anti_aliasing=True, mode='constant', 
+        preserve_range=True, multichannel=False)
+    if rescale_to_orig:
+        return resize(im2, im.shape, anti_aliasing=False, mode='constant',
+            preserve_range=True)
+    return im2
 
 def _percentile_clip(a, perc=80):
     return np.mean(trimboth(np.sort(a, axis=0), (100 - perc)/100, axis=0), axis=0)
@@ -33,13 +51,27 @@ def modify_hue(x, shift):
     x = x + shift
     return x
 
-class MultiSpectral(Component):
-
-    colour_binning = ConfigParserProperty(
-        1, 'Colour', 'colour_binning', 'app', val_type=int)
-    subtract_colour_gradients = ConfigParserProperty(
-        1, 'Colour', 'subtract_colour_gradients', 'app', val_type=int)
+class MultiSpectral(Component, Settings):
     
+    save_settings = ['saturation', 'colour_stretch', 'redgreen', 'yellowblue']
+
+    bin_colour = BooleanProperty(True)
+    compensation = StringProperty('subtract gradients')
+    #subtract_gradients = BooleanProperty(True)
+    #subtract_background = BooleanProperty(False)
+
+    tab_name = 'LAB Colour'
+    configurables = [
+        ('bin_colour', {
+            'name': 'bin colour?', 
+            'switch': '',
+            'help': 'Binning the colour channels helps reduce colour noise'}),
+        ('compensation', {
+            'name': 'compensation', 
+            'options': ['none', 'subtract background', 'subtract gradients'],
+            'help': 'done prior to colour scaling (subtract gradents recommended)'})
+        ]
+
     saturation = NumericProperty(0)
     colour_stretch = NumericProperty(.5)
     redgreen = NumericProperty(0)
@@ -124,7 +156,7 @@ class MultiSpectral(Component):
             Component.get('Stacker').get_stack(filt='all'))
 
     def luminance_updated(self, lum):
-        # called from monochrome if user updates luminance control e.g. white
+        # called from monochrome if user updates luminance control e.g. white
 
         self.lum = lum
         # we are in LRGB mode
@@ -139,10 +171,10 @@ class MultiSpectral(Component):
         else:            
             Component.get('View').display_image(lum)
 
-    def on_colour_binning(self, *args):
+    def on_bin_colour(self, *args):
         self.create_LAB()
 
-    def on_subtract_colour_gradients(self, *args):
+    def on_subtract_gradients(self, *args):
         self.create_LAB()
 
     ''' Colour processes are daisy-chained and intermediate representations cached for speed        
@@ -156,10 +188,6 @@ class MultiSpectral(Component):
     def create_LAB(self):
         # Initial stage of LAB image creation from RGB stacks
 
-        def bin(im, binfac=2):
-            im2 = rescale(im, 1 / binfac, anti_aliasing=True, mode='constant', multichannel=False)
-            return resize(im2, im.shape, anti_aliasing=False, mode='constant')
-
         def _limit(im):
             im[im < 0] = 0
             im[im > 1] = 1
@@ -170,24 +198,33 @@ class MultiSpectral(Component):
 
         ims = [self.R, self.G, self.B]
 
-        # binning ~ 70 ms
-        if self.colour_binning:
-            ims = [bin(im) for im in ims]
+        # binning ~ 70 ms
+        if self.bin_colour:
+            ims = [bin_image(im) for im in ims]
 
-        # alternative approach to test
-        # might also add option to not subtract anything.... just to test
-        if self.subtract_colour_gradients:
+        # compensation prior to scaling
+        if self.compensation == 'subtract gradients':
             ims = [im - estimate_gradient(im) for im in ims]
-        else:
+        elif self.compensation == 'subtract background':
             ims = [im - estimate_background(im)[0] for im in ims]
 
-        # it turns out this value is absolutely critical because setting it too low means that stars get saturated
-        # whereas too high, or just using the absolute max leads to a colour space is too compressed (too grey).
-
+        ''' the percentile is absolutely critical: setting too low
+            leads to saturated stars; too high leads to a washed-out
+            colour space
+        '''
         max_pixel_vals = [np.percentile(im.ravel(), 99.99) for im in ims]
+
+        ''' divide all images by the largest of these; this expands the
+            colour dynamic range without affected colour ratios; the expanded
+            range helps when L is combined
+        '''
         ims = [im / max(max_pixel_vals) for im in ims]
 
-        # now limit image to 0-1 because we are about to stretch
+        ''' limit image to 0-1 because we are about to stretch
+            (while it shouldn't be necessary as we've just divided by
+            max feature, there may be some brighter hot pixels 
+            above unity)
+        '''
         self.normed_RGB = [_limit(im) for im in ims]
 
         # rest of process
@@ -207,7 +244,7 @@ class MultiSpectral(Component):
         return all([hasattr(self, p) and getattr(self, p) is not None for p in props])
 
     def adjust_colour_stretch(self, *args):
-        # intercept LAB process here if we need to stretch colour
+        # intercept LAB process here if we need to stretch colour
 
         if self.avail('layer'):
             self.layer_stretch_changed()
@@ -219,7 +256,7 @@ class MultiSpectral(Component):
             self.adjust_saturation()
 
     def adjust_saturation(self, *args):
-        # Modify saturation and call next process
+        # Modify saturation and call next process
         
         if self.avail('layer'):
             self.layer_sat_changed()
@@ -230,12 +267,12 @@ class MultiSpectral(Component):
             self.adjust_hue() # next process in hue adjustment
 
     def adjust_hue(self, *args):
-        # Modify hue and generate RGB image
+        # Modify hue and generate RGB image
         
         if self.avail('A_sat'):
             self.A_hue = modify_hue(self.A_sat, self.redgreen)
             self.B_hue = modify_hue(self.B_sat, self.yellowblue)
-            self.create_RGB()  # next process
+            self.create_RGB()  # next process
 
     def create_RGB(self):
         ''' Combine L, A and B into RGB image. Called here when previous colour process
