@@ -3,14 +3,13 @@
 
 import math
 import os
-import time
 import operator
 from functools import partial
 from datetime import datetime
 import numpy as np
+from loguru import logger
 
 from kivy.app import App
-from kivy.logger import Logger
 from kivy.core.window import Window
 from kivy.uix.floatlayout import FloatLayout
 from kivy.uix.boxlayout import BoxLayout
@@ -21,7 +20,8 @@ from kivy.uix.label import Label
 from kivy.lang import Builder
 from kivy.properties import NumericProperty, StringProperty, BooleanProperty
 from kivy.metrics import dp
-from kivy.clock import Clock
+
+from jocular.utils import toast
 
 Builder.load_string('''
 
@@ -38,7 +38,8 @@ Builder.load_string('''
     browser: None
     halign: 'center'
     background_color: .08, .08, .08, 1
-    color: app.highlight_color
+    # color: app.highlight_color
+    color: app.theme_cls.primary_color
 
 # row label
 <TableLabel>:
@@ -72,7 +73,8 @@ Builder.load_string('''
     browser: None
     halign: 'center'
     #background_normal: ''
-    color: app.highlight_color
+    # color: app.highlight_color
+    color: app.theme_cls.primary_color
     background_color: .06, .06, .06, 0
 
 <SearchBarTextInput@TextInput>:
@@ -145,7 +147,7 @@ Builder.load_string('''
                 width: root.width - dp(30)
                 orientation: 'vertical'
 
-            Slider:
+            MDSlider:
                 size_hint: None, 1
                 cursor_size: [dp(25), dp(25)]
                 width: dp(30)
@@ -428,8 +430,10 @@ class SearchBar(BoxLayout):
         pass
 
     def combine_results(self):
+        # these two lines ~ 10ms
         l = [s.filtered for s in self.filters]
         self.table.search_results = list(set.intersection(*l)) # causes update
+        # this takes ~ 50ms
         self.table.on_search_results()
 
     def reapply_filters(self):
@@ -504,6 +508,11 @@ class SearchFilter(SearchBarTextInput):
         to avoid multiple identical updates.
         '''
 
+        ''' Timing-wise, the search is pretty fast actually about 30ms for 40k rows; takes longer to then
+            intersect the results and redraw; could be worth optimising for large catalogues, but not yet
+        '''
+
+
         value = value.strip()
 
         if not value:
@@ -530,8 +539,6 @@ class SearchFilter(SearchBarTextInput):
                     objs = {k: v.lower() for k, v in objs.items()}
                     value = value.lower()
 
-                    # to do: had ! or != for not equal
-
                     # use wildcard syntax, and = for exact match
                     if value[0] == '*':
                         if len(value) > 1:
@@ -548,6 +555,7 @@ class SearchFilter(SearchBarTextInput):
                             value = value[:-1]
                         objs = {k: v for k, v in objs.items() if v.startswith(value)}
 
+
                 elif self.column_type in [float, int]:
 
                     objs = {k: col_type(v) for k, v in objs.items()}
@@ -598,13 +606,13 @@ class SearchFilter(SearchBarTextInput):
                             elif op == '<':
                                 objs = {k: v for k, v in objs.items() if v <= comp_value}
 
-
             self.filtered = set(objs.keys())
 
             # update search results by intersecting with current search results from other columns
+            # also does the redraw so quite expensive
             self.table.searchbar.combine_results()
 
-        except Exception:
+        except Exception as e:
             pass
 
 #-------------------------------------------------------------------------------------------
@@ -626,8 +634,7 @@ class Table(FloatLayout):
         update_on_show=True, on_show_method=None, on_hide_method=None, 
         initial_sort_column=None, initial_sort_direction=None, **kwargs):
 
-
-        t0 = time.time()
+        logger.debug('Building {:}'.format(name))
         self.initialising = True  # to prevent redraw
         super().__init__(**kwargs)
 
@@ -666,24 +673,17 @@ class Table(FloatLayout):
         self.initialising = False  # now allow redraw
         self.size = Window.size
         self.redraw()
-        Logger.debug('Table: {:} built in {:.0f} ms'.format(name, 1000*(time.time() - t0)))
+        # the redraw takes the time
+        logger.debug('built')
 
 
     def redraw(self, *args):
 
-        def make_rows():
-            h = self.height - self.myheader.height - self.footer.height
-            nrows = int(h / self.empty_row.height)
-            spare = h - nrows * self.empty_row.height
-            rows = []
-            for i in range(0, nrows):
-                r = TableRow(self)
-                rows.append(r)
-            return rows, len(rows), spare
-        
         if self.initialising:
             return
 
+        # t0 = time.time()
+
         self.redrawing = True
 
         if not hasattr(self, 'header'):
@@ -693,16 +693,25 @@ class Table(FloatLayout):
             self.searchbar = SearchBar(self)
             self.myheader.add_widget(self.searchbar)
             self.empty_row = TableRow(self)
-            self.rows, self.n_rows, spare = make_rows()
         else: # remove rows
             for r in self.rows:
                 self.contents.remove_widget(r)
 
-        self.rows, self.n_rows, spare = make_rows()
+        # new in v0.5
+        h = self.height - self.myheader.height - self.footer.height
+        nrows = int(h / self.empty_row.height)
+        spare = h - nrows * self.empty_row.height
+        self.rows = []
+        for i in range(0, nrows):
+            r = TableRow(self)
+            self.rows.append(r)
+        self.n_rows = len(self.rows)
+
         for r in self.rows:
             self.contents.add_widget(r)
         self.spacer.height = spare
 
+        # about 300 ms for DSO table
         self.footer_actions.clear_widgets()
         if self.actions:
             for k, v in self.actions.items():
@@ -713,11 +722,13 @@ class Table(FloatLayout):
  
         self.redrawing = False
 
-        # self.sort_column()
+        # about 100 ms for DSO table
         self.on_search_results()
+
         if self.initial_sort_direction is not None:
             self.sort_column(reverse=self.initial_sort_direction)
 
+
     def on_search_results(self, *args):
 
         if self.initialising: #  or self.redrawing:
@@ -748,7 +759,7 @@ class Table(FloatLayout):
             if r in self.data:
                 self.rows[i].update_row(self.data[r], key=r)
             else:
-                Logger.debug('Table: cannot find {:} in table'.format(r))
+                logger.warning('cannot find {:} in table'.format(r))
 
         for j in range(last_row - self.current_row, self.n_rows):  # clear rest
             self.rows[j].update_row(self.empty_row, empty=True)
@@ -798,12 +809,7 @@ class Table(FloatLayout):
         self.update_display()
 
     def export(self, but):
-        def no_nl(s):
-            return s.replace('\n', ' ')
 
-        self.export_button = but
-        self.orig_export_button_color = but.color
-        but.color = [1, 0, 0, 1]
         cols = self.cols.keys()
         when = datetime.now().strftime('%d_%b_%y_%H_%M')
 
@@ -814,12 +820,9 @@ class Table(FloatLayout):
             cols = [v.get('field', k) for k, v in self.cols.items()]
             for s in self.search_results:
                 sd = self.data[s]
-                f.write(','.join([no_nl(str(sd.get(c,''))) for c in cols]))
+                f.write(','.join([str(sd.get(c,'')).replace('\n', ' ') for c in cols]))
                 f.write('\n')
-        Clock.schedule_once(self.change_export_button, 1)
-
-    def change_export_button(self, dt):
-        self.export_button.color = self.orig_export_button_color
+        toast('Exported to {:}'.format(path), duration=3)
 
     def get_selected(self):
         return self.selected
